@@ -3,7 +3,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: win32gui.cpp 923 2013-01-27 10:41:11Z murdoch $
+// $Id: win32gui.cpp 960 2013-08-28 14:34:44Z murdoch $
 
 #include "win32gui.hpp"
 
@@ -431,8 +431,7 @@ GLFont* Win32WindowImpl::getFont(const char* family, int style, double cex,
         endGL();
       }
       UNPROTECT(1);
-    }  
-    return fonts[0];
+    }
   } else { // useFreeType
 #ifdef HAVE_FREETYPE
     char fontname_absolute[MAX_PATH+1] = "";
@@ -466,8 +465,15 @@ GLFont* Win32WindowImpl::getFont(const char* family, int style, double cex,
     }
     UNPROTECT(1);
 #endif
-    return fonts[0];  
   }
+  if (strcmp(family, fonts[0]->family)) warning("font family \"%s\" not found, using \"%s\"", 
+                                         family, fonts[0]->family);
+  else if (style != fonts[0]->style) warning("\"%s\" family only supports font %d", 
+                                        fonts[0]->family, fonts[0]->style);
+  else if (cex != fonts[0]->cex) warning("\"%s\" family only supports cex = %g",
+  					fonts[0]->family, fonts[0]->cex);
+  else if (useFreeType) warning("FreeType font not available");
+  return fonts[0];
 }
 
 GLBitmapFont* Win32WindowImpl::initGLBitmapFont(u8 firstGlyph, u8 lastGlyph) 
